# <div align="center">

<h2>
    OpenVoicePlus: Advanced Python Library for OpenVoice
</h2>
<div>
    <img width="500" alt="teaser" src="doc/melo_logo.png">
</div>
<div>
    <a href="https://pypi.org/project/openvoiceplus" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/openvoiceplus.svg?color=%2334D058" alt="Supported Python versions">
    </a>
    <a href="https://badge.fury.io/py/openvoiceplus"><img src="https://badge.fury.io/py/openvoiceplus.svg" alt="pypi version"></a>
</div>
</div>

## 🛠️ Installation

```bash
pip install openvoiceplus
```

## 🎙️ Usage

```python

```

## 😍 Contributing

```bash
pip install pre-commit
pre-commit install
pre-commit run --all-files
```

## 📜 License

This project is licensed under the terms of the MIT License.

## 🤗 Citation

```bibtex
@article{qin2023openvoice,
  title={OpenVoice: Versatile Instant Voice Cloning},
  author={Qin, Zengyi and Zhao, Wenliang and Yu, Xumin and Sun, Xin},
  journal={arXiv preprint arXiv:2312.01479},
  year={2023}
}
```
